/*
 * alarm-announce.js
 *
 * Copyright (c) 2006 by Daniel Potter.  All rights reserved.
 *
 * This file is part of the Vana'diel Clock.
 *
 * The Vana'diel Clock is free software; you can redistribute
 * it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * The Vana'diel Clock is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Vana'diel Clock; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 *
 * Handles setting up the alarm dialog.
 */

var alarmTitle = null;
var alarmAnimate = false;
var alarmFinalHeight = 32;
var alarmOpenTime = 3000;

// Evenutally these might be customizable:
var alarmSlideTime = 10;
var alarmSlideIncrement = 1;

function setupAlarms() {
    // get the alarms from the window arguments
    var tabbed = true;
    if ("arguments" in window && window.arguments.length > 0) {
	var alarms = window.arguments;
	// see if the arguments contains a single array
	if ("length" in alarms[0]) {
	    alarms = alarms[0];
	    if (window.arguments.length >= 2) {
		tabbed = window.arguments[1] ? true : false;
		// that stupid "normalize to boolean" crap always looks stupid
		if (window.arguments.length >= 3) {
		    if (window.arguments[2])
			alarmAnimate = true;
		}
	    }
	}
	var tabs = null;
	var root = document.getElementById("main-box");
	var buttons = document.getElementById("button-box");
	if (alarms.length > 1 && tabbed) {
	    // create tabs
	    var tabbox = document.createElement("tabbox");
	    tabbox.setAttribute("flex", "1");
	    root.insertBefore(tabbox, buttons);
	    tabs = document.createElement("tabs");
	    tabbox.appendChild(tabs);
	    root = document.createElement("tabpanels");
	    root.setAttribute("flex", "1");
	    tabbox.appendChild(root);
	} else {
	    alarmTitle = alarms[0].name;
	}
	for (var i in alarms) {
	    var alarm = alarms[i];
	    var parent = root;
	    if (tabs != null) {
		var tab = document.createElement("tab");
		tab.setAttribute("label", alarm.name);
		tabs.appendChild(tab);
		parent = document.createElement("tabpanel");
		root.appendChild(parent);
	    }
	    var ae = document.createElement("alarm");
	    ae.setAttribute("name", alarm.name);
	    ae.setAttribute("icon", alarm.icon);
	    ae.appendChild(document.createTextNode(alarm.description));
	    if (tabs == null)
		parent.insertBefore(ae, buttons);
	    else
		parent.appendChild(ae);
	}
	// increase the time we're open based on how much we're showing
	alarmOpenTime *= alarms.length;
    } else {
	// erp
	var l = document.createElement("label");
	l.setAttribute("value", "Error: no alarms given to dialog");
	document.documentElement.appendChild(l);
    }
}

function init() {
    if (alarmAnimate) {
	document.documentElement.className = "popup";

	// size us to fit
	sizeToContent();

	alarmFinalHeight = window.outerHeight;
	// We kind of "slide" up
	window.outerHeight = 1;

	// be sure to offset the alert by 10 pixels from the far right edge of the screen
	window.moveTo( (screen.availLeft + screen.availWidth - window.outerWidth) - 10, screen.availTop + screen.availHeight - window.outerHeight);

	setTimeout(animateAlarm, alarmSlideTime);
    } else {
	// size us to fit
	sizeToContent();

	// center us on the window (I hope)
	var x = Math.floor((screen.availWidth - window.outerWidth) / 2);
	var y = Math.floor((screen.availHeight - window.outerHeight) / 2);
	window.moveTo(x > 0 ? x : 0, y > 0 ? y : 0);
	if (alarmTitle != null)
	    document.title = alarmTitle;
	window.focus();
    }
}

function animateAlarm() {
    var n = window.outerHeight + alarmSlideIncrement;
    if (n >= alarmFinalHeight) {
	window.screenY -= n - alarmFinalHeight;
	window.outerHeight = alarmFinalHeight;
	setTimeout(closeAlarm, alarmOpenTime);
    } else {
	window.screenY -= alarmSlideIncrement;
	window.outerHeight = n;
	setTimeout(animateAlarm, alarmSlideTime);
    }
}

function closeAlarm() {
    var n = window.outerHeight - alarmSlideIncrement;
    if (n <= 1) {
	window.close();
    } else {
	window.screenY += alarmSlideIncrement;
	window.outerHeight = n;
	setTimeout(closeAlarm, alarmSlideTime);
    }
}
