/*
 * vanadiel-clock.js
 *
 * Copyright (c) 2005 by Daniel Potter.  All rights reserved.
 *
 * This file is part of the Vana'diel Clock.
 *
 * The Vana'diel Clock is free software; you can redistribute
 * it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * The Vana'diel Clock is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Vana'diel Clock; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 *
 * Utility functions for handling Vana'diel dates.
 */

// XPCOM stuff

// Topic indicating that the preferences for the Vana'diel clock have changed
const VANADIEL_PREF_CLOCK_TOPIC = "vanadielclock:prefs";

// Name of Vana'diel days - note that these days are the value we give to the
// "day" attribute on our time marker to set the day icon.

const vanaDays = [ "fire", "earth", "water", "wind", "ice", "thunder", "light", "dark" ];

var vanaLocalNames = new Array(vanaDays.length);

// Name of moon phases, used to look up the phase name and set the moon icon
const moonPhases = [ "new", "waxingcrescent.1", "waxingcrescent.2", "firstquarter", "waxinggibbous.1", "waxinggibbous.2", "full", "waninggibbous.1", "waninggibbous.2", "lastquarter", "waningcrescent.1", "waningcrescent.2" ];

var moonPhaseLocalNames = new Array();
var moonPhaseLocalWaxing;
var moonPhaseLocalWaning;

var VanadielClock_TimerService = Components.classes["@xenoveritas.org/vanadiel-timer;1"].
               getService(Components.interfaces.nsIVanadielTimer);

function VanadielClock_init() {
    // Load our localized strings
    var strBundleService = Components.classes["@mozilla.org/intl/stringbundle;1"].getService(Components.interfaces.nsIStringBundleService);
    var strings = strBundleService.createBundle("chrome://vanadielclock/locale/clock.properties");

    for (var i in vanaDays) {
	vanaLocalNames[i] = strings.GetStringFromName("day." + vanaDays[i]);
    }
    for (var i in moonPhases) {
	moonPhaseLocalNames[i] = strings.GetStringFromName("moon." + moonPhases[i]);
    }
    moonPhaseLocalWaxing = strings.GetStringFromName("moon.waxing");
    moonPhaseLocalWaning = strings.GetStringFromName("moon.waning");
}

// Creates a JavaScript Date based on a Vana'diel time
function VanadielClock_convertToEarthDate(vanaTime) {
    return new Date((Math.floor(vanaTime/25)*1000)+VanadielClock_TimerService.vanadielOffset - VanadielClock_TimerService.realTimeOffset);
}

function VanadielClock_showOptions() {
    VanadielClock_openWindow("chrome://vanadielclock/content/options.xul", "optwin", "chrome");
}

function VanadielClock_showAdvancedDisplay() {
    VanadielClock_openWindow("chrome://vanadielclock/content/advanced-display.xul", "vcadvwin", "chrome,dialog=no");
}

function VanadielClock_showAbout() {
    VanadielClock_openWindow("chrome://vanadielclock/content/about.xul", "vcaboutwin", "chrome,dependent");
}

function VanadielClock_showAlarms() {
    VanadielClock_openWindow("chrome://vanadielclock/content/alarms.xul", "vcalarms", "chrome,resizable=yes,dialog=no");
}

function VanadielClock_setAlarm() {
    // open the "set alarm" dialog
    window.openDialog("chrome://vanadielclock/content/alarm-properties.xul", "_blank", "chrome", "new");
}

function VanadielClock_showTimeHelp() {
    VanadielClock_openWindow("chrome://vanadielclock/content/synchronize-time.xul", "vcsync", "chrome,dialog=no");
}

function VanadielClock_openWindow(url, id, options, arguments) {
    var win = window.openDialog(url, id, options, arguments);
    if (win) {
      win.focus();
    }
}
